@@ -1,6 +1,9 @@
 """tables_io is a library of functions for input, output and conversion of tabular data formats"""
 
-from ._version import version
+try:
+    from ._version import version
+except:  #pragma: no cover
+    version = "unknown"
 
 from .lazy_modules import *
 
